pub struct DomainDetection {
pub domain: DomainId,
pub activated: bool,
pub confidence: f64,
pub evidence: Vec<String>,
}Expand description
Evidence that a domain package activates for a workspace.
Fields
domain: DomainIdactivated: boolconfidence: f64Confidence in [0, 1].
evidence: Vec<String>Trait Implementations
Sourceimpl Clone for DomainDetection
impl Clone for DomainDetection
Sourcefn clone(&self) -> DomainDetection
fn clone(&self) -> DomainDetection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DomainDetection
impl Debug for DomainDetection
Sourceimpl<'de> Deserialize<'de> for DomainDetection
impl<'de> Deserialize<'de> for DomainDetection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DomainDetection
impl PartialEq for DomainDetection
Sourcefn eq(&self, other: &DomainDetection) -> bool
fn eq(&self, other: &DomainDetection) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DomainDetection
impl Serialize for DomainDetection
impl StructuralPartialEq for DomainDetection